\name{inNucleus}
\alias{inNucleus}

\title{A function to determine those proteins annotated by the nucleus
  GO term.}
\description{
This function takes the experimental y2h data as well as an estimate for
an in silico interactome (ISI) and determines which protein complexes of
the ISI has more than 75 percent of the constituent member proteins
annotated by the nucleus GO term. 
}
\usage{
inNucleus(y2h, ISI = NULL)
}

\arguments{
  \item{y2h}{A three tiered list. Names of the second tier corresponds to
  ID of experiment. Names of the third tier should be the bait
  proteins. The entries of the third tier are character vectors of
  proteins detected as prey}
  \item{ISI}{The incidence matrix of the bi-partite graph representation
  of the in silico interactome.}
}

\value{

  \item{nucProt}{A character vector of those proteins annotated to the nucleus}
  \item{nucComp}{An incidence matrix of the bipartite graph
    representation of the ISI with the restriction that only complexes
    with 75 percent of its constituent members are annnotated by the
    nucleus term.}
  \item{nuclearY2H}{A data structure exactly like the input y2h, except
    that the prey proteins are restricted to those which are annotated
    by the nucleus term}

}

\author{T Chiang}

\examples{
data(y2hSysGW)
eg=y2hSysGW[3]
inNucleus(eg)
}
\keyword{datagen}